@@ -131,7 +131,8 @@ class CollectionScanner(GObject.GObject, TagReader):
                 self.__pending_new_artist_ids.remove(artist_id)
 
         item.lp_album_id = get_lollypop_album_id(item.album_name,
-                                                 item.album_artists)
+                                                 item.album_artists,
+                                                 item.year)
         Logger.debug("CollectionScanner::save_track(): Add album: "
                      "%s, %s" % (item.album_name, item.album_artist_ids))
         (item.new_album, item.album_id) = self.add_album(
@@ -212,7 +213,7 @@ class CollectionScanner(GObject.GObject, TagReader):
             different artists
             @param item as CollectionItem
         """
-        if item.album_artist_ids:
+        if item.album_artist_ids and not item.compilation:
             App().albums.set_artist_ids(item.album_id, item.album_artist_ids)
         # Set artist ids based on content
         else:
@@ -230,7 +231,8 @@ class CollectionScanner(GObject.GObject, TagReader):
                     self.__pending_new_artist_ids.remove(artist_id)
         # Update lp_album_id
         lp_album_id = get_lollypop_album_id(item.album_name,
-                                            item.album_artists)
+                                            item.album_artists,
+                                            item.year)
         if lp_album_id != item.lp_album_id:
             App().album_art.move(item.lp_album_id, lp_album_id)
             App().albums.set_lp_album_id(item.album_id, lp_album_id)
@@ -503,6 +505,8 @@ class CollectionScanner(GObject.GObject, TagReader):
                 self.__flatpak_migration()
                 App().notify.send("Lollypop",
                                   _("Scan disabled, missing collection"))
+                App().settings.set_value("flatpak-access-migration",
+                                         GLib.Variant("b", True))
                 return
             if scan_type == ScanType.NEW_FILES:
                 db_uris = App().tracks.get_uris(uris)
@@ -870,5 +874,3 @@ class CollectionScanner(GObject.GObject, TagReader):
             assistant.set_position(Gtk.WindowPosition.CENTER_ON_PARENT)
             assistant.set_transient_for(App().window)
             GLib.timeout_add(1000, assistant.show)
-            App().settings.set_value("flatpak-access-migration",
-                                     GLib.Variant("b", True))
