@@ -53,13 +53,12 @@ class FullScreen(Gtk.Window, SignalsHelper):
         self.__signal1_id = self.__signal2_id = None
         self.__background_id = None
         self.set_decorated(False)
-        scale_factor = self.get_scale_factor()
-        art_size = ArtSize.FULLSCREEN / scale_factor
-        font_size = 30 / scale_factor
+        art_size = ArtSize.FULLSCREEN
+        font_size = 30
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/FullScreen.ui")
         builder.connect_signals(self)
-        self.__progress_widget = ProgressPlayerWidget()
+        self.__progress_widget = ProgressPlayerWidget(True)
         self.__progress_widget.show()
         self.__progress_widget.set_property("halign", Gtk.Align.CENTER)
         self.__progress_widget.set_size_request(500, -1)
