@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -51,7 +51,7 @@ class NotificationManager:
                 App().is_fullscreen:
             return
 
-        cover_path = App().art.get_album_cache_path(track.album,
+        cover_path = App().album_art.get_cache_path(track.album,
                                                     ArtSize.BIG,
                                                     ArtSize.BIG)
         if cover_path is None:
