@@ -276,7 +276,10 @@ class TagReader:
             if not compilation:
                 compilation = self.__get_extended(tags, ["COMPILATION"])
             if compilation:
-                return bool(compilation)
+                return compilation == 1
+            artists = self.get_album_artists(tags)
+            if artists.lower() == "various artists":
+                return True
         except Exception as e:
             Logger.error("TagReader::get_compilation(): %s" % e)
         return False
